# SPDX-FileCopyrightText: 2021 Carter Nelson for Adafruit Industries
# SPDX-License-Identifier: MIT

# This example shows using TCA9548A to perform a simple scan for connected devices
import board
import adafruit_tca9548a


# what we are looking for are the address 0x49, which should show up on both port 0 and port 1.
# that address, 0x49, is the address for the spectral sensors, which can't be changed at the sensors
# so we need the multiplexer to let us talk to each of them
# the other available devices will show up in the listing. It's safe to ignore them here.

# code.py output:
# Channel 0:['0x30', '0x44', '0x49', '0x68', '0x77']    will see '0x49' here if the spectral sensor is plugged in
# Channel 1:['0x30', '0x44', '0x49', '0x68', '0x77']    will see '0x49' here if the spectral sensor is plugged in
# Channel 2:['0x30', '0x44', '0x68', '0x77']
# Channel 3:['0x30', '0x44', '0x68', '0x77']
# Channel 4:['0x30', '0x44', '0x68', '0x77']
# Channel 5:['0x30', '0x44', '0x68', '0x77']
# Channel 6:['0x30', '0x44', '0x68', '0x77']
# Channel 7:['0x30', '0x44', '0x68', '0x77']


# Create I2C bus as normal
i2c = board.I2C()  # uses board.SCL and board.SDA
# i2c = board.STEMMA_I2C()  # For using the built-in STEMMA QT connector on a microcontroller

# Create the TCA9548A object and give it the I2C bus
tca = adafruit_tca9548a.TCA9548A(i2c)

for channel in range(8):
    if tca[channel].try_lock():
        print("Channel {}:".format(channel), end="")
        addresses = tca[channel].scan()
        print([hex(address) for address in addresses if address != 0x70])
        tca[channel].unlock()
