import time
import board
import busio

from adafruit_as726x import AS726x_I2C
import adafruit_tca9548a


# Create I2C bus as normal
i2c = board.I2C()  # uses board.SCL and board.SDA

# Create the TCA9548A object and give it the I2C bus
tca = adafruit_tca9548a.TCA9548A(i2c)

# Initialize I2C bus and sensor.

NIR_sensor = AS726x_I2C( tca[0])
VIS_sensor = AS726x_I2C( tca[1])

# choose one or the other of the sensors to test:
# the library is written such that it only expects the VIS sensor,
# so the NIR band labels are incorrect, but otherwise the code works on both sensors
#sensor = NIR_sensor
sensor = VIS_sensor

sensor.conversion_mode = sensor.MODE_2

print( "Default Gain = {}".format( sensor.gain ))
sensor.gain = 16
print( "Gain Now = {}".format( sensor.gain ))

print( "Default Integration Time = {} ms".format( sensor.integration_time ))
sensor.integration_time = 166
print( "Integration Time Now = {} ms".format( sensor.integration_time ))


sensor.driver_led_current = 50 #mA
sensor.driver_led = True
time.sleep(1.0)
sensor.driver_led = False

while True:
    # Wait for data to be ready
    while not sensor.data_ready:
        time.sleep(.1)

#Calibration information from AS7262 datasheet:
#Each channel is tested with GAIN = 16x, Integration Time (INT_T) = 166ms and VDD = VDD1 = VDD2 = 3.3V, TAMB=25°C.
#The accuracy of the channel counts/μW/cm2 is ±12%.
#Sensor Mode 2 is a continuous conversion of light into data on all 6 channels
#450nm, 500nm, 550nm, 570nm, 600nm and 650nm

#sensor.violet returns the calibrated floating point value in the violet channel.
#sensor.raw_violet returns the uncalibrated decimal count value in the violet channel.
#that syntax is the same for all 6 channels


    print( "V:450nm: %0.1f" % sensor.violet )
    print( "B:500nm: %0.1f" % sensor.blue )
    print( "G:550nm: %0.1f" % sensor.green )
    print( "Y:570nm: %0.1f" % sensor.yellow )
    print( "O:600nm: %0.1f" % sensor.orange )
    print( "R:650nm: %0.1f" % sensor.red )
    print( "Sensor Temperature: %0.1f" % sensor.temperature )
    print()
    time.sleep(1)
